@@ -8,7 +8,7 @@
 
 import time
 
-from .Scheduler import dbg, get_db_index
+from .common.tools import get_db_index, dbg
 from .construct_file import frame_constructor
 from .dbserver.base import Base
 from .dbserver.data_manager import data_manager
@@ -27,8 +27,9 @@ class Data(object):
             db_index = get_db_index(db_config)
             Base_pool[db_index] = Base
         dbg('Auto init success!')
-    except:
-        dbg('Did not find a db config file, need run Data.init(db_config) manually...')
+    except Exception as e:
+        dbg(str(e))
+        dbg('Did not find a db config file, need run Data.init(db_config) manually...[from normal_connect]')
         # Base = None
 
     @staticmethod
@@ -144,9 +145,9 @@ class Data(object):
         if show_manager_id is True:
             dbg('本次任务通过', base_id, '执行')
         # dbg(params)
-        return Data.Base_pool[base_id].update(table, conditions, or_cond, params,
+        Data.Base_pool[base_id].update(table, conditions, or_cond, params,
                                        show_sql) if base_id in Data.Base_pool else None
-
+        return
 
     # update data
 
@@ -215,7 +216,6 @@ class Data(object):
             return table_index
         except Exception as e:
             dbg(str(e))
-
     # dump database as an Anduin-data-frame
 
     @staticmethod
